# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class spider(object):

    def __init__(self, zap):
        self.zap = zap

    def status(self, scanid=None):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        params = {}
        if scanid is not None:
            params['scanId'] = scanid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/status/', params)))

    def results(self, scanid=None):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        params = {}
        if scanid is not None:
            params['scanId'] = scanid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/results/', params)))

    def full_results(self, scanid):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/fullResults/', {'scanId': scanid})))

    @property
    def scans(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/scans/')))

    @property
    def excluded_from_scan(self):
        """
        Gets the regexes of URLs excluded from the spider scans.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/excludedFromScan/')))

    @property
    def all_urls(self):
        """
        Returns a list of unique URLs from the history table based on HTTP messages added by the Spider.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/allUrls/')))

    def added_nodes(self, scanid=None):
        """
        Returns a list of the names of the nodes added to the Sites tree by the specified scan.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {}
        if scanid is not None:
            params['scanId'] = scanid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/addedNodes/', params)))

    @property
    def domains_always_in_scope(self):
        """
        Gets all the domains that are always in scope. For each domain the following are shown: the index, the value (domain), if enabled, and if specified as a regex.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/domainsAlwaysInScope/')))

    @property
    def option_domains_always_in_scope(self):
        """
        Use view domainsAlwaysInScope instead.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionDomainsAlwaysInScope/')))

    @property
    def option_domains_always_in_scope_enabled(self):
        """
        Use view domainsAlwaysInScope instead.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionDomainsAlwaysInScopeEnabled/')))

    @property
    def option_handle_parameters(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionHandleParameters/')))

    @property
    def option_max_children(self):
        """
        Gets the maximum number of child nodes (per node) that can be crawled, 0 means no limit.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionMaxChildren/')))

    @property
    def option_max_depth(self):
        """
        Gets the maximum depth the spider can crawl, 0 if unlimited.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionMaxDepth/')))

    @property
    def option_max_duration(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionMaxDuration/')))

    @property
    def option_max_parse_size_bytes(self):
        """
        Gets the maximum size, in bytes, that a response might have to be parsed.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionMaxParseSizeBytes/')))

    @property
    def option_max_scans_in_ui(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionMaxScansInUI/')))

    @property
    def option_request_wait_time(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionRequestWaitTime/')))

    @property
    def option_skip_url_string(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionSkipURLString/')))

    @property
    def option_thread_count(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionThreadCount/')))

    @property
    def option_user_agent(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionUserAgent/')))

    @property
    def option_accept_cookies(self):
        """
        Gets whether or not a spider process should accept cookies while spidering.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionAcceptCookies/')))

    @property
    def option_handle_o_data_parameters_visited(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionHandleODataParametersVisited/')))

    @property
    def option_parse_comments(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionParseComments/')))

    @property
    def option_parse_git(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionParseGit/')))

    @property
    def option_parse_robots_txt(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionParseRobotsTxt/')))

    @property
    def option_parse_svn_entries(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionParseSVNEntries/')))

    @property
    def option_parse_sitemap_xml(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionParseSitemapXml/')))

    @property
    def option_post_form(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionPostForm/')))

    @property
    def option_process_form(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionProcessForm/')))

    @property
    def option_send_referer_header(self):
        """
        Gets whether or not the 'Referer' header should be sent while spidering.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionSendRefererHeader/')))

    @property
    def option_show_advanced_dialog(self):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/view/optionShowAdvancedDialog/')))

    def scan(self, url=None, maxchildren=None, recurse=None, contextname=None, subtreeonly=None, apikey=''):
        """
        Runs the spider against the given URL (or context). Optionally, the 'maxChildren' parameter can be set to limit the number of children scanned, the 'recurse' parameter can be used to prevent the spider from seeding recursively, the parameter 'contextName' can be used to constrain the scan to a Context and the parameter 'subtreeOnly' allows to restrict the spider under a site's subtree (using the specified 'url').
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'apikey': apikey}
        if url is not None:
            params['url'] = url
        if maxchildren is not None:
            params['maxChildren'] = maxchildren
        if recurse is not None:
            params['recurse'] = recurse
        if contextname is not None:
            params['contextName'] = contextname
        if subtreeonly is not None:
            params['subtreeOnly'] = subtreeonly
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/scan/', params)))

    def scan_as_user(self, contextid, userid, url=None, maxchildren=None, recurse=None, subtreeonly=None, apikey=''):
        """
        Runs the spider from the perspective of a User, obtained using the given Context ID and User ID. See 'scan' action for more details.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'contextId': contextid, 'userId': userid, 'apikey': apikey}
        if url is not None:
            params['url'] = url
        if maxchildren is not None:
            params['maxChildren'] = maxchildren
        if recurse is not None:
            params['recurse'] = recurse
        if subtreeonly is not None:
            params['subtreeOnly'] = subtreeonly
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/scanAsUser/', params)))

    def pause(self, scanid, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/pause/', {'scanId': scanid, 'apikey': apikey})))

    def resume(self, scanid, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/resume/', {'scanId': scanid, 'apikey': apikey})))

    def stop(self, scanid=None, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'apikey': apikey}
        if scanid is not None:
            params['scanId'] = scanid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/stop/', params)))

    def remove_scan(self, scanid, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/removeScan/', {'scanId': scanid, 'apikey': apikey})))

    def pause_all_scans(self, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/pauseAllScans/', {'apikey': apikey})))

    def resume_all_scans(self, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/resumeAllScans/', {'apikey': apikey})))

    def stop_all_scans(self, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/stopAllScans/', {'apikey': apikey})))

    def remove_all_scans(self, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/removeAllScans/', {'apikey': apikey})))

    def clear_excluded_from_scan(self, apikey=''):
        """
        Clears the regexes of URLs excluded from the spider scans.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/clearExcludedFromScan/', {'apikey': apikey})))

    def exclude_from_scan(self, regex, apikey=''):
        """
        Adds a regex of URLs that should be excluded from the spider scans.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/excludeFromScan/', {'regex': regex, 'apikey': apikey})))

    def add_domain_always_in_scope(self, value, isregex=None, isenabled=None, apikey=''):
        """
        Adds a new domain that's always in scope, using the specified value. Optionally sets if the new entry is enabled (default, true) and whether or not the new value is specified as a regex (default, false).
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'value': value, 'apikey': apikey}
        if isregex is not None:
            params['isRegex'] = isregex
        if isenabled is not None:
            params['isEnabled'] = isenabled
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/addDomainAlwaysInScope/', params)))

    def modify_domain_always_in_scope(self, idx, value=None, isregex=None, isenabled=None, apikey=''):
        """
        Modifies a domain that's always in scope. Allows to modify the value, if enabled or if a regex. The domain is selected with its index, which can be obtained with the view domainsAlwaysInScope.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'idx': idx, 'apikey': apikey}
        if value is not None:
            params['value'] = value
        if isregex is not None:
            params['isRegex'] = isregex
        if isenabled is not None:
            params['isEnabled'] = isenabled
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/modifyDomainAlwaysInScope/', params)))

    def remove_domain_always_in_scope(self, idx, apikey=''):
        """
        Removes a domain that's always in scope, with the given index. The index can be obtained with the view domainsAlwaysInScope.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/removeDomainAlwaysInScope/', {'idx': idx, 'apikey': apikey})))

    def enable_all_domains_always_in_scope(self, apikey=''):
        """
        Enables all domains that are always in scope.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/enableAllDomainsAlwaysInScope/', {'apikey': apikey})))

    def disable_all_domains_always_in_scope(self, apikey=''):
        """
        Disables all domains that are always in scope.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/disableAllDomainsAlwaysInScope/', {'apikey': apikey})))

    def set_option_handle_parameters(self, string, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionHandleParameters/', {'String': string, 'apikey': apikey})))

    def set_option_skip_url_string(self, string, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionSkipURLString/', {'String': string, 'apikey': apikey})))

    def set_option_user_agent(self, string, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionUserAgent/', {'String': string, 'apikey': apikey})))

    def set_option_accept_cookies(self, boolean, apikey=''):
        """
        Sets whether or not a spider process should accept cookies while spidering.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionAcceptCookies/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_handle_o_data_parameters_visited(self, boolean, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionHandleODataParametersVisited/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_max_children(self, integer, apikey=''):
        """
        Sets the maximum number of child nodes (per node) that can be crawled, 0 means no limit.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionMaxChildren/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_depth(self, integer, apikey=''):
        """
        Sets the maximum depth the spider can crawl, 0 for unlimited depth.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionMaxDepth/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_duration(self, integer, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionMaxDuration/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_parse_size_bytes(self, integer, apikey=''):
        """
        Sets the maximum size, in bytes, that a response might have to be parsed. This allows the spider to skip big responses/files.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionMaxParseSizeBytes/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_scans_in_ui(self, integer, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionMaxScansInUI/', {'Integer': integer, 'apikey': apikey})))

    def set_option_parse_comments(self, boolean, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionParseComments/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_parse_git(self, boolean, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionParseGit/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_parse_robots_txt(self, boolean, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionParseRobotsTxt/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_parse_svn_entries(self, boolean, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionParseSVNEntries/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_parse_sitemap_xml(self, boolean, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionParseSitemapXml/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_post_form(self, boolean, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionPostForm/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_process_form(self, boolean, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionProcessForm/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_request_wait_time(self, integer, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionRequestWaitTime/', {'Integer': integer, 'apikey': apikey})))

    def set_option_send_referer_header(self, boolean, apikey=''):
        """
        Sets whether or not the 'Referer' header should be sent while spidering.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionSendRefererHeader/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_show_advanced_dialog(self, boolean, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionShowAdvancedDialog/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_thread_count(self, integer, apikey=''):
        """
        
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'spider/action/setOptionThreadCount/', {'Integer': integer, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class core(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def hosts(self):
        """
        Gets the name of the hosts accessed through/by ZAP
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/hosts/')))

    @property
    def sites(self):
        """
        Gets the sites accessed through/by ZAP (scheme and domain)
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/sites/')))

    def urls(self, baseurl=None):
        """
        Gets the URLs accessed through/by ZAP, optionally filtering by (base) URL.
        """
        params = {}
        if baseurl is not None:
            params['baseurl'] = baseurl
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/urls/', params)))

    def child_nodes(self, url=None):
        """
        Gets the child nodes underneath the specified URL in the Sites tree
        """
        params = {}
        if url is not None:
            params['url'] = url
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/childNodes/', params)))

    def message(self, id):
        """
        Gets the HTTP message with the given ID. Returns the ID, request/response headers and bodies, cookies, note, type, RTT, and timestamp.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/message/', {'id': id})))

    def messages(self, baseurl=None, start=None, count=None):
        """
        Gets the HTTP messages sent by ZAP, request and response, optionally filtered by URL and paginated with 'start' position and 'count' of messages
        """
        params = {}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/messages/', params)))

    def messages_by_id(self, ids):
        """
        Gets the HTTP messages with the given IDs.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/messagesById/', {'ids': ids})))

    def number_of_messages(self, baseurl=None):
        """
        Gets the number of messages, optionally filtering by URL
        """
        params = {}
        if baseurl is not None:
            params['baseurl'] = baseurl
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/numberOfMessages/', params)))

    @property
    def mode(self):
        """
        Gets the mode
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/mode/')))

    @property
    def version(self):
        """
        Gets ZAP version
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/version/')))

    @property
    def excluded_from_proxy(self):
        """
        Gets the regular expressions, applied to URLs, to exclude from the local proxies.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/excludedFromProxy/')))

    @property
    def session_location(self):
        """
        Gets the location of the current session file
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/sessionLocation/')))

    @property
    def proxy_chain_excluded_domains(self):
        """
        Gets all the domains that are excluded from the outgoing proxy. For each domain the following are shown: the index, the value (domain), if enabled, and if specified as a regex.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/proxyChainExcludedDomains/')))

    @property
    def zap_home_path(self):
        """
        Gets the path to ZAP's home directory.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/zapHomePath/')))

    @property
    def option_maximum_alert_instances(self):
        """
        Gets the maximum number of alert instances to include in a report.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionMaximumAlertInstances/')))

    @property
    def option_merge_related_alerts(self):
        """
        Gets whether or not related alerts will be merged in any reports generated.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionMergeRelatedAlerts/')))

    @property
    def option_alert_overrides_file_path(self):
        """
        Gets the path to the file with alert overrides.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionAlertOverridesFilePath/')))

    @property
    def home_directory(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/homeDirectory/')))

    @property
    def option_proxy_chain_skip_name(self):
        """
        Use view proxyChainExcludedDomains instead.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionProxyChainSkipName/')))

    @property
    def option_proxy_excluded_domains(self):
        """
        Use view proxyChainExcludedDomains instead.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionProxyExcludedDomains/')))

    @property
    def option_proxy_excluded_domains_enabled(self):
        """
        Use view proxyChainExcludedDomains instead.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionProxyExcludedDomainsEnabled/')))

    def alert(self, id):
        """
        Gets the alert with the given ID, the corresponding HTTP message can be obtained with the 'messageId' field and 'message' API method
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/alert/', {'id': id})))

    def alerts(self, baseurl=None, start=None, count=None, riskid=None):
        """
        Gets the alerts raised by ZAP, optionally filtering by URL or riskId, and paginating with 'start' position and 'count' of alerts
        """
        params = {}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        if riskid is not None:
            params['riskId'] = riskid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/alerts/', params)))

    def alerts_summary(self, baseurl=None):
        """
        Gets number of alerts grouped by each risk level, optionally filtering by URL
        """
        params = {}
        if baseurl is not None:
            params['baseurl'] = baseurl
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/alertsSummary/', params)))

    def number_of_alerts(self, baseurl=None, riskid=None):
        """
        Gets the number of alerts, optionally filtering by URL or riskId
        """
        params = {}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if riskid is not None:
            params['riskId'] = riskid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/numberOfAlerts/', params)))

    @property
    def option_default_user_agent(self):
        """
        Gets the user agent that ZAP should use when creating HTTP messages (for example, spider messages or CONNECT requests to outgoing proxy).
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionDefaultUserAgent/')))

    @property
    def option_dns_ttl_successful_queries(self):
        """
        Gets the TTL (in seconds) of successful DNS queries.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionDnsTtlSuccessfulQueries/')))

    @property
    def option_http_state(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionHttpState/')))

    @property
    def option_http_state_enabled(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionHttpStateEnabled/')))

    @property
    def option_proxy_chain_name(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionProxyChainName/')))

    @property
    def option_proxy_chain_password(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionProxyChainPassword/')))

    @property
    def option_proxy_chain_port(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionProxyChainPort/')))

    @property
    def option_proxy_chain_prompt(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionProxyChainPrompt/')))

    @property
    def option_proxy_chain_realm(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionProxyChainRealm/')))

    @property
    def option_proxy_chain_user_name(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionProxyChainUserName/')))

    @property
    def option_single_cookie_request_header(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionSingleCookieRequestHeader/')))

    @property
    def option_timeout_in_secs(self):
        """
        Gets the connection time out (in seconds).
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionTimeoutInSecs/')))

    @property
    def option_use_proxy_chain(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionUseProxyChain/')))

    @property
    def option_use_proxy_chain_auth(self):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionUseProxyChainAuth/')))

    @property
    def option_use_socks_proxy(self):
        """
        Gets whether or not the SOCKS proxy should be used.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/view/optionUseSocksProxy/')))

    def access_url(self, url, followredirects=None, apikey=''):
        """
        Convenient and simple action to access a URL, optionally following redirections. Returns the request sent and response received and followed redirections, if any. Other actions are available which offer more control on what is sent, like, 'sendRequest' or 'sendHarRequest'.
        """
        params = {'url': url, 'apikey': apikey}
        if followredirects is not None:
            params['followRedirects'] = followredirects
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/accessUrl/', params)))

    def shutdown(self, apikey=''):
        """
        Shuts down ZAP
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/shutdown/', {'apikey': apikey})))

    def new_session(self, name=None, overwrite=None, apikey=''):
        """
        Creates a new session, optionally overwriting existing files. If a relative path is specified it will be resolved against the "session" directory in ZAP "home" dir.
        """
        params = {'apikey': apikey}
        if name is not None:
            params['name'] = name
        if overwrite is not None:
            params['overwrite'] = overwrite
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/newSession/', params)))

    def load_session(self, name, apikey=''):
        """
        Loads the session with the given name. If a relative path is specified it will be resolved against the "session" directory in ZAP "home" dir.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/loadSession/', {'name': name, 'apikey': apikey})))

    def save_session(self, name, overwrite=None, apikey=''):
        """
        Saves the session.
        """
        params = {'name': name, 'apikey': apikey}
        if overwrite is not None:
            params['overwrite'] = overwrite
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/saveSession/', params)))

    def snapshot_session(self, name=None, overwrite=None, apikey=''):
        """
        Snapshots the session, optionally with the given name, and overwriting existing files. If no name is specified the name of the current session with a timestamp appended is used. If a relative path is specified it will be resolved against the "session" directory in ZAP "home" dir.
        """
        params = {'apikey': apikey}
        if name is not None:
            params['name'] = name
        if overwrite is not None:
            params['overwrite'] = overwrite
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/snapshotSession/', params)))

    def clear_excluded_from_proxy(self, apikey=''):
        """
        Clears the regexes of URLs excluded from the local proxies.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/clearExcludedFromProxy/', {'apikey': apikey})))

    def exclude_from_proxy(self, regex, apikey=''):
        """
        Adds a regex of URLs that should be excluded from the local proxies.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/excludeFromProxy/', {'regex': regex, 'apikey': apikey})))

    def set_home_directory(self, dir, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setHomeDirectory/', {'dir': dir, 'apikey': apikey})))

    def set_mode(self, mode, apikey=''):
        """
        Sets the mode, which may be one of [safe, protect, standard, attack]
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setMode/', {'mode': mode, 'apikey': apikey})))

    def generate_root_ca(self, apikey=''):
        """
        Generates a new Root CA certificate for the local proxies.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/generateRootCA/', {'apikey': apikey})))

    def send_request(self, request, followredirects=None, apikey=''):
        """
        Sends the HTTP request, optionally following redirections. Returns the request sent and response received and followed redirections, if any. The Mode is enforced when sending the request (and following redirections), custom manual requests are not allowed in 'Safe' mode nor in 'Protected' mode if out of scope.
        """
        params = {'request': request, 'apikey': apikey}
        if followredirects is not None:
            params['followRedirects'] = followredirects
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/sendRequest/', params)))

    def run_garbage_collection(self, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/runGarbageCollection/', {'apikey': apikey})))

    def delete_site_node(self, url, method=None, postdata=None, apikey=''):
        """
        Deletes the site node found in the Sites Tree on the basis of the URL, HTTP method, and post data (if applicable and specified). 
        """
        params = {'url': url, 'apikey': apikey}
        if method is not None:
            params['method'] = method
        if postdata is not None:
            params['postData'] = postdata
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/deleteSiteNode/', params)))

    def add_proxy_chain_excluded_domain(self, value, isregex=None, isenabled=None, apikey=''):
        """
        Adds a domain to be excluded from the outgoing proxy, using the specified value. Optionally sets if the new entry is enabled (default, true) and whether or not the new value is specified as a regex (default, false).
        """
        params = {'value': value, 'apikey': apikey}
        if isregex is not None:
            params['isRegex'] = isregex
        if isenabled is not None:
            params['isEnabled'] = isenabled
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/addProxyChainExcludedDomain/', params)))

    def modify_proxy_chain_excluded_domain(self, idx, value=None, isregex=None, isenabled=None, apikey=''):
        """
        Modifies a domain excluded from the outgoing proxy. Allows to modify the value, if enabled or if a regex. The domain is selected with its index, which can be obtained with the view proxyChainExcludedDomains.
        """
        params = {'idx': idx, 'apikey': apikey}
        if value is not None:
            params['value'] = value
        if isregex is not None:
            params['isRegex'] = isregex
        if isenabled is not None:
            params['isEnabled'] = isenabled
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/modifyProxyChainExcludedDomain/', params)))

    def remove_proxy_chain_excluded_domain(self, idx, apikey=''):
        """
        Removes a domain excluded from the outgoing proxy, with the given index. The index can be obtained with the view proxyChainExcludedDomains.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/removeProxyChainExcludedDomain/', {'idx': idx, 'apikey': apikey})))

    def enable_all_proxy_chain_excluded_domains(self, apikey=''):
        """
        Enables all domains excluded from the outgoing proxy.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/enableAllProxyChainExcludedDomains/', {'apikey': apikey})))

    def disable_all_proxy_chain_excluded_domains(self, apikey=''):
        """
        Disables all domains excluded from the outgoing proxy.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/disableAllProxyChainExcludedDomains/', {'apikey': apikey})))

    def set_option_maximum_alert_instances(self, numberofinstances, apikey=''):
        """
        Sets the maximum number of alert instances to include in a report. A value of zero is treated as unlimited.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionMaximumAlertInstances/', {'numberOfInstances': numberofinstances, 'apikey': apikey})))

    def set_option_merge_related_alerts(self, enabled, apikey=''):
        """
        Sets whether or not related alerts will be merged in any reports generated.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionMergeRelatedAlerts/', {'enabled': enabled, 'apikey': apikey})))

    def set_option_alert_overrides_file_path(self, filepath=None, apikey=''):
        """
        Sets (or clears, if empty) the path to the file with alert overrides.
        """
        params = {'apikey': apikey}
        if filepath is not None:
            params['filePath'] = filepath
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionAlertOverridesFilePath/', params)))

    def enable_pkcs_12_client_certificate(self, filepath, password, index=None, apikey=''):
        """
        Enables use of a PKCS12 client certificate for the certificate with the given file system path, password, and optional index.
        """
        params = {'filePath': filepath, 'password': password, 'apikey': apikey}
        if index is not None:
            params['index'] = index
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/enablePKCS12ClientCertificate/', params)))

    def disable_client_certificate(self, apikey=''):
        """
        Disables the option for use of client certificates.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/disableClientCertificate/', {'apikey': apikey})))

    def delete_all_alerts(self, apikey=''):
        """
        Deletes all alerts of the current session.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/deleteAllAlerts/', {'apikey': apikey})))

    def delete_alert(self, id, apikey=''):
        """
        Deletes the alert with the given ID. 
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/deleteAlert/', {'id': id, 'apikey': apikey})))

    def set_option_default_user_agent(self, string, apikey=''):
        """
        Sets the user agent that ZAP should use when creating HTTP messages (for example, spider messages or CONNECT requests to outgoing proxy).
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionDefaultUserAgent/', {'String': string, 'apikey': apikey})))

    def set_option_dns_ttl_successful_queries(self, integer, apikey=''):
        """
        Sets the TTL (in seconds) of successful DNS queries (applies after ZAP restart).
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionDnsTtlSuccessfulQueries/', {'Integer': integer, 'apikey': apikey})))

    def set_option_http_state_enabled(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionHttpStateEnabled/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_proxy_chain_name(self, string, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionProxyChainName/', {'String': string, 'apikey': apikey})))

    def set_option_proxy_chain_password(self, string, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionProxyChainPassword/', {'String': string, 'apikey': apikey})))

    def set_option_proxy_chain_port(self, integer, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionProxyChainPort/', {'Integer': integer, 'apikey': apikey})))

    def set_option_proxy_chain_prompt(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionProxyChainPrompt/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_proxy_chain_realm(self, string, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionProxyChainRealm/', {'String': string, 'apikey': apikey})))

    def set_option_proxy_chain_skip_name(self, string, apikey=''):
        """
        Use actions [add|modify|remove]ProxyChainExcludedDomain instead.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionProxyChainSkipName/', {'String': string, 'apikey': apikey})))

    def set_option_proxy_chain_user_name(self, string, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionProxyChainUserName/', {'String': string, 'apikey': apikey})))

    def set_option_single_cookie_request_header(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionSingleCookieRequestHeader/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_timeout_in_secs(self, integer, apikey=''):
        """
        Sets the connection time out (in seconds).
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionTimeoutInSecs/', {'Integer': integer, 'apikey': apikey})))

    def set_option_use_proxy_chain(self, boolean, apikey=''):
        """
        Sets whether or not the outgoing proxy should be used. The address/hostname of the outgoing proxy must be set to enable this option.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionUseProxyChain/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_use_proxy_chain_auth(self, boolean, apikey=''):
        """
        
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionUseProxyChainAuth/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_use_socks_proxy(self, boolean, apikey=''):
        """
        Sets whether or not the SOCKS proxy should be used.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'core/action/setOptionUseSocksProxy/', {'Boolean': boolean, 'apikey': apikey})))

    def proxy_pac(self, apikey=''):
        """
        
        """
        return (self.zap._request_other(self.zap.base_other + 'core/other/proxy.pac/', {'apikey': apikey}))

    def rootcert(self, apikey=''):
        """
        Gets the Root CA certificate used by the local proxies.
        """
        return (self.zap._request_other(self.zap.base_other + 'core/other/rootcert/', {'apikey': apikey}))

    def setproxy(self, proxy, apikey=''):
        """
        
        """
        return (self.zap._request_other(self.zap.base_other + 'core/other/setproxy/', {'proxy': proxy, 'apikey': apikey}))

    def xmlreport(self, apikey=''):
        """
        Generates a report in XML format
        """
        return (self.zap._request_other(self.zap.base_other + 'core/other/xmlreport/', {'apikey': apikey}))

    def htmlreport(self, apikey=''):
        """
        Generates a report in HTML format
        """
        return (self.zap._request_other(self.zap.base_other + 'core/other/htmlreport/', {'apikey': apikey}))

    def jsonreport(self, apikey=''):
        """
        Generates a report in JSON format
        """
        return (self.zap._request_other(self.zap.base_other + 'core/other/jsonreport/', {'apikey': apikey}))

    def mdreport(self, apikey=''):
        """
        Generates a report in Markdown format
        """
        return (self.zap._request_other(self.zap.base_other + 'core/other/mdreport/', {'apikey': apikey}))

    def message_har(self, id, apikey=''):
        """
        Gets the message with the given ID in HAR format
        """
        return (self.zap._request_other(self.zap.base_other + 'core/other/messageHar/', {'id': id, 'apikey': apikey}))

    def messages_har(self, baseurl=None, start=None, count=None, apikey=''):
        """
        Gets the HTTP messages sent through/by ZAP, in HAR format, optionally filtered by URL and paginated with 'start' position and 'count' of messages
        """
        params = {'apikey': apikey}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return (self.zap._request_other(self.zap.base_other + 'core/other/messagesHar/', params))

    def messages_har_by_id(self, ids, apikey=''):
        """
        Gets the HTTP messages with the given IDs, in HAR format.
        """
        return (self.zap._request_other(self.zap.base_other + 'core/other/messagesHarById/', {'ids': ids, 'apikey': apikey}))

    def send_har_request(self, request, followredirects=None, apikey=''):
        """
        Sends the first HAR request entry, optionally following redirections. Returns, in HAR format, the request sent and response received and followed redirections, if any. The Mode is enforced when sending the request (and following redirections), custom manual requests are not allowed in 'Safe' mode nor in 'Protected' mode if out of scope.
        """
        params = {'request': request, 'apikey': apikey}
        if followredirects is not None:
            params['followRedirects'] = followredirects
        return (self.zap._request_other(self.zap.base_other + 'core/other/sendHarRequest/', params))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class replacer(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def rules(self):
        """
        Returns full details of all of the rules
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'replacer/view/rules/')))

    def add_rule(self, description, enabled, matchtype, matchregex, matchstring, replacement=None, initiators=None, url=None, apikey=''):
        """
        Adds a replacer rule. For the parameters: desc is a user friendly description, enabled is true or false, matchType is one of [REQ_HEADER, REQ_HEADER_STR, REQ_BODY_STR, RESP_HEADER, RESP_HEADER_STR, RESP_BODY_STR], matchRegex should be true if the matchString should be treated as a regex otherwise false, matchString is the string that will be matched against, replacement is the replacement string, initiators may be blank (for all initiators) or a comma separated list of integers as defined in <a href="https://github.com/zaproxy/zaproxy/blob/main/zap/src/main/java/org/parosproxy/paros/network/HttpSender.java">HttpSender</a>  
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'description': description, 'enabled': enabled, 'matchType': matchtype, 'matchRegex': matchregex, 'matchString': matchstring, 'apikey': apikey}
        if replacement is not None:
            params['replacement'] = replacement
        if initiators is not None:
            params['initiators'] = initiators
        if url is not None:
            params['url'] = url
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'replacer/action/addRule/', params)))

    def remove_rule(self, description, apikey=''):
        """
        Removes the rule with the given description
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'replacer/action/removeRule/', {'description': description, 'apikey': apikey})))

    def set_enabled(self, description, bool, apikey=''):
        """
        Enables or disables the rule with the given description based on the bool parameter  
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'replacer/action/setEnabled/', {'description': description, 'bool': bool, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class search(object):

    def __init__(self, zap):
        self.zap = zap

    def urls_by_url_regex(self, regex, baseurl=None, start=None, count=None):
        """
        Returns the URLs of the HTTP messages that match the given regular expression in the URL optionally filtered by URL and paginated with 'start' position and 'count' of messages.
        """
        params = {'regex': regex}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'search/view/urlsByUrlRegex/', params)))

    def urls_by_request_regex(self, regex, baseurl=None, start=None, count=None):
        """
        Returns the URLs of the HTTP messages that match the given regular expression in the request optionally filtered by URL and paginated with 'start' position and 'count' of messages.
        """
        params = {'regex': regex}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'search/view/urlsByRequestRegex/', params)))

    def urls_by_response_regex(self, regex, baseurl=None, start=None, count=None):
        """
        Returns the URLs of the HTTP messages that match the given regular expression in the response optionally filtered by URL and paginated with 'start' position and 'count' of messages.
        """
        params = {'regex': regex}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'search/view/urlsByResponseRegex/', params)))

    def urls_by_header_regex(self, regex, baseurl=None, start=None, count=None):
        """
        Returns the URLs of the HTTP messages that match the given regular expression in the header(s) optionally filtered by URL and paginated with 'start' position and 'count' of messages.
        """
        params = {'regex': regex}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'search/view/urlsByHeaderRegex/', params)))

    def messages_by_url_regex(self, regex, baseurl=None, start=None, count=None):
        """
        Returns the HTTP messages that match the given regular expression in the URL optionally filtered by URL and paginated with 'start' position and 'count' of messages.
        """
        params = {'regex': regex}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'search/view/messagesByUrlRegex/', params)))

    def messages_by_request_regex(self, regex, baseurl=None, start=None, count=None):
        """
        Returns the HTTP messages that match the given regular expression in the request optionally filtered by URL and paginated with 'start' position and 'count' of messages.
        """
        params = {'regex': regex}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'search/view/messagesByRequestRegex/', params)))

    def messages_by_response_regex(self, regex, baseurl=None, start=None, count=None):
        """
        Returns the HTTP messages that match the given regular expression in the response optionally filtered by URL and paginated with 'start' position and 'count' of messages.
        """
        params = {'regex': regex}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'search/view/messagesByResponseRegex/', params)))

    def messages_by_header_regex(self, regex, baseurl=None, start=None, count=None):
        """
        Returns the HTTP messages that match the given regular expression in the header(s) optionally filtered by URL and paginated with 'start' position and 'count' of messages.
        """
        params = {'regex': regex}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'search/view/messagesByHeaderRegex/', params)))

    def har_by_url_regex(self, regex, baseurl=None, start=None, count=None, apikey=''):
        """
        Returns the HTTP messages, in HAR format, that match the given regular expression in the URL optionally filtered by URL and paginated with 'start' position and 'count' of messages.
        """
        params = {'regex': regex, 'apikey': apikey}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return (self.zap._request_other(self.zap.base_other + 'search/other/harByUrlRegex/', params))

    def har_by_request_regex(self, regex, baseurl=None, start=None, count=None, apikey=''):
        """
        Returns the HTTP messages, in HAR format, that match the given regular expression in the request optionally filtered by URL and paginated with 'start' position and 'count' of messages.
        """
        params = {'regex': regex, 'apikey': apikey}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return (self.zap._request_other(self.zap.base_other + 'search/other/harByRequestRegex/', params))

    def har_by_response_regex(self, regex, baseurl=None, start=None, count=None, apikey=''):
        """
        Returns the HTTP messages, in HAR format, that match the given regular expression in the response optionally filtered by URL and paginated with 'start' position and 'count' of messages.
        """
        params = {'regex': regex, 'apikey': apikey}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return (self.zap._request_other(self.zap.base_other + 'search/other/harByResponseRegex/', params))

    def har_by_header_regex(self, regex, baseurl=None, start=None, count=None, apikey=''):
        """
        Returns the HTTP messages, in HAR format, that match the given regular expression in the header(s) optionally filtered by URL and paginated with 'start' position and 'count' of messages.
        """
        params = {'regex': regex, 'apikey': apikey}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return (self.zap._request_other(self.zap.base_other + 'search/other/harByHeaderRegex/', params))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class network(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def get_root_ca_cert_validity(self):
        """
        Gets the Root CA certificate validity, in days. Used when generating a new Root CA certificate.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/getRootCaCertValidity/')))

    @property
    def get_server_cert_validity(self):
        """
        Gets the server certificate validity, in days. Used when generating server certificates.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/getServerCertValidity/')))

    @property
    def get_aliases(self):
        """
        Gets the aliases used to identify the local servers/proxies.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/getAliases/')))

    @property
    def get_local_servers(self):
        """
        Gets the local servers/proxies.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/getLocalServers/')))

    @property
    def get_pass_throughs(self):
        """
        Gets the authorities that will pass-through the local proxies.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/getPassThroughs/')))

    @property
    def get_connection_timeout(self):
        """
        Gets the connection timeout, in seconds.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/getConnectionTimeout/')))

    @property
    def get_default_user_agent(self):
        """
        Gets the default user-agent.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/getDefaultUserAgent/')))

    @property
    def get_dns_ttl_successful_queries(self):
        """
        Gets the TTL (in seconds) of successful DNS queries.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/getDnsTtlSuccessfulQueries/')))

    @property
    def get_http_proxy(self):
        """
        Gets the HTTP proxy.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/getHttpProxy/')))

    @property
    def get_http_proxy_exclusions(self):
        """
        Gets the HTTP proxy exclusions.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/getHttpProxyExclusions/')))

    @property
    def get_socks_proxy(self):
        """
        Gets the SOCKS proxy.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/getSocksProxy/')))

    @property
    def is_http_proxy_auth_enabled(self):
        """
        Tells whether or not the HTTP proxy authentication is enabled.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/isHttpProxyAuthEnabled/')))

    @property
    def is_http_proxy_enabled(self):
        """
        Tells whether or not the HTTP proxy is enabled.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/isHttpProxyEnabled/')))

    @property
    def is_socks_proxy_enabled(self):
        """
        Tells whether or not the SOCKS proxy is enabled.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/isSocksProxyEnabled/')))

    @property
    def is_use_global_http_state(self):
        """
        Tells whether or not to use global HTTP state.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/view/isUseGlobalHttpState/')))

    def generate_root_ca_cert(self, apikey=''):
        """
        Generates a new Root CA certificate, used to issue server certificates.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/generateRootCaCert/', {'apikey': apikey})))

    def import_root_ca_cert(self, filepath, apikey=''):
        """
        Imports a Root CA certificate to be used to issue server certificates.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/importRootCaCert/', {'filePath': filepath, 'apikey': apikey})))

    def set_root_ca_cert_validity(self, validity, apikey=''):
        """
        Sets the Root CA certificate validity. Used when generating a new Root CA certificate.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setRootCaCertValidity/', {'validity': validity, 'apikey': apikey})))

    def set_server_cert_validity(self, validity, apikey=''):
        """
        Sets the server certificate validity. Used when generating server certificates.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setServerCertValidity/', {'validity': validity, 'apikey': apikey})))

    def add_alias(self, name, enabled=None, apikey=''):
        """
        Adds an alias for the local servers/proxies.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'name': name, 'apikey': apikey}
        if enabled is not None:
            params['enabled'] = enabled
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/addAlias/', params)))

    def add_local_server(self, address, port, api=None, proxy=None, behindnat=None, decoderesponse=None, removeacceptencoding=None, apikey=''):
        """
        Adds a local server/proxy.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'address': address, 'port': port, 'apikey': apikey}
        if api is not None:
            params['api'] = api
        if proxy is not None:
            params['proxy'] = proxy
        if behindnat is not None:
            params['behindNat'] = behindnat
        if decoderesponse is not None:
            params['decodeResponse'] = decoderesponse
        if removeacceptencoding is not None:
            params['removeAcceptEncoding'] = removeacceptencoding
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/addLocalServer/', params)))

    def add_pass_through(self, authority, enabled=None, apikey=''):
        """
        Adds an authority to pass-through the local proxies.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'authority': authority, 'apikey': apikey}
        if enabled is not None:
            params['enabled'] = enabled
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/addPassThrough/', params)))

    def remove_alias(self, name, apikey=''):
        """
        Removes an alias.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/removeAlias/', {'name': name, 'apikey': apikey})))

    def remove_local_server(self, address, port, apikey=''):
        """
        Removes a local server/proxy.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/removeLocalServer/', {'address': address, 'port': port, 'apikey': apikey})))

    def remove_pass_through(self, authority, apikey=''):
        """
        Removes a pass-through.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/removePassThrough/', {'authority': authority, 'apikey': apikey})))

    def set_alias_enabled(self, name, enabled, apikey=''):
        """
        Sets whether or not an alias is enabled.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setAliasEnabled/', {'name': name, 'enabled': enabled, 'apikey': apikey})))

    def set_pass_through_enabled(self, authority, enabled, apikey=''):
        """
        Sets whether or not a pass-through is enabled.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setPassThroughEnabled/', {'authority': authority, 'enabled': enabled, 'apikey': apikey})))

    def set_connection_timeout(self, timeout, apikey=''):
        """
        Sets the timeout, for reads and connects.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setConnectionTimeout/', {'timeout': timeout, 'apikey': apikey})))

    def set_default_user_agent(self, useragent, apikey=''):
        """
        Sets the default user-agent.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setDefaultUserAgent/', {'userAgent': useragent, 'apikey': apikey})))

    def set_dns_ttl_successful_queries(self, ttl, apikey=''):
        """
        Sets the TTL of successful DNS queries.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setDnsTtlSuccessfulQueries/', {'ttl': ttl, 'apikey': apikey})))

    def add_http_proxy_exclusion(self, host, enabled=None, apikey=''):
        """
        Adds a host to be excluded from the HTTP proxy.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'host': host, 'apikey': apikey}
        if enabled is not None:
            params['enabled'] = enabled
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/addHttpProxyExclusion/', params)))

    def remove_http_proxy_exclusion(self, host, apikey=''):
        """
        Removes a HTTP proxy exclusion.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/removeHttpProxyExclusion/', {'host': host, 'apikey': apikey})))

    def set_http_proxy(self, host, port, realm=None, username=None, password=None, apikey=''):
        """
        Sets the HTTP proxy configuration.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'host': host, 'port': port, 'apikey': apikey}
        if realm is not None:
            params['realm'] = realm
        if username is not None:
            params['username'] = username
        if password is not None:
            params['password'] = password
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setHttpProxy/', params)))

    def set_http_proxy_auth_enabled(self, enabled, apikey=''):
        """
        Sets whether or not the HTTP proxy authentication is enabled.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setHttpProxyAuthEnabled/', {'enabled': enabled, 'apikey': apikey})))

    def set_http_proxy_enabled(self, enabled, apikey=''):
        """
        Sets whether or not the HTTP proxy is enabled.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setHttpProxyEnabled/', {'enabled': enabled, 'apikey': apikey})))

    def set_http_proxy_exclusion_enabled(self, host, enabled, apikey=''):
        """
        Sets whether or not a HTTP proxy exclusion is enabled.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setHttpProxyExclusionEnabled/', {'host': host, 'enabled': enabled, 'apikey': apikey})))

    def set_socks_proxy(self, host, port, version=None, usedns=None, username=None, password=None, apikey=''):
        """
        Sets the SOCKS proxy configuration.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'host': host, 'port': port, 'apikey': apikey}
        if version is not None:
            params['version'] = version
        if usedns is not None:
            params['useDns'] = usedns
        if username is not None:
            params['username'] = username
        if password is not None:
            params['password'] = password
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setSocksProxy/', params)))

    def set_socks_proxy_enabled(self, enabled, apikey=''):
        """
        Sets whether or not the SOCKS proxy is enabled.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setSocksProxyEnabled/', {'enabled': enabled, 'apikey': apikey})))

    def set_use_global_http_state(self, use, apikey=''):
        """
        Sets whether or not to use the global HTTP state.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setUseGlobalHttpState/', {'use': use, 'apikey': apikey})))

    def add_pkcs_12_client_certificate(self, filepath, password, index=None, apikey=''):
        """
        Adds a client certificate contained in a PKCS#12 file, the certificate is automatically set as active and used.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'filePath': filepath, 'password': password, 'apikey': apikey}
        if index is not None:
            params['index'] = index
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/addPkcs12ClientCertificate/', params)))

    def set_use_client_certificate(self, use, apikey=''):
        """
        Sets whether or not to use the active client certificate.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'network/action/setUseClientCertificate/', {'use': use, 'apikey': apikey})))

    def proxy_pac(self, apikey=''):
        """
        Provides a PAC file, proxying through the main proxy.
        This component is optional and therefore the API will only work if it is installed
        """
        return (self.zap._request_other(self.zap.base_other + 'network/other/proxy.pac/', {'apikey': apikey}))

    def set_proxy(self, proxy, apikey=''):
        """
        Sets the HTTP proxy configuration.
        This component is optional and therefore the API will only work if it is installed
        """
        return (self.zap._request_other(self.zap.base_other + 'network/other/setProxy/', {'proxy': proxy, 'apikey': apikey}))

    def root_ca_cert(self, apikey=''):
        """
        Gets the Root CA certificate used to issue server certificates. Suitable to import into client applications (e.g. browsers).
        This component is optional and therefore the API will only work if it is installed
        """
        return (self.zap._request_other(self.zap.base_other + 'network/other/rootCaCert/', {'apikey': apikey}))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class selenium(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def option_browser_extensions(self):
        """
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/view/optionBrowserExtensions/')))

    @property
    def option_chrome_binary_path(self):
        """
        Returns the current path to Chrome binary
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/view/optionChromeBinaryPath/')))

    @property
    def option_chrome_driver_path(self):
        """
        Returns the current path to ChromeDriver
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/view/optionChromeDriverPath/')))

    @property
    def option_firefox_binary_path(self):
        """
        Returns the current path to Firefox binary
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/view/optionFirefoxBinaryPath/')))

    @property
    def option_firefox_driver_path(self):
        """
        Returns the current path to Firefox driver (geckodriver)
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/view/optionFirefoxDriverPath/')))

    @property
    def option_ie_driver_path(self):
        """
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/view/optionIeDriverPath/')))

    @property
    def option_last_directory(self):
        """
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/view/optionLastDirectory/')))

    @property
    def option_phantom_js_binary_path(self):
        """
        Returns the current path to PhantomJS binary
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/view/optionPhantomJsBinaryPath/')))

    def set_option_chrome_binary_path(self, string, apikey=''):
        """
        Sets the current path to Chrome binary
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/action/setOptionChromeBinaryPath/', {'String': string, 'apikey': apikey})))

    def set_option_chrome_driver_path(self, string, apikey=''):
        """
        Sets the current path to ChromeDriver
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/action/setOptionChromeDriverPath/', {'String': string, 'apikey': apikey})))

    def set_option_firefox_binary_path(self, string, apikey=''):
        """
        Sets the current path to Firefox binary
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/action/setOptionFirefoxBinaryPath/', {'String': string, 'apikey': apikey})))

    def set_option_firefox_driver_path(self, string, apikey=''):
        """
        Sets the current path to Firefox driver (geckodriver)
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/action/setOptionFirefoxDriverPath/', {'String': string, 'apikey': apikey})))

    def set_option_ie_driver_path(self, string, apikey=''):
        """
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/action/setOptionIeDriverPath/', {'String': string, 'apikey': apikey})))

    def set_option_last_directory(self, string, apikey=''):
        """
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/action/setOptionLastDirectory/', {'String': string, 'apikey': apikey})))

    def set_option_phantom_js_binary_path(self, string, apikey=''):
        """
        Sets the current path to PhantomJS binary
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'selenium/action/setOptionPhantomJsBinaryPath/', {'String': string, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class importLogFiles(object):

    def __init__(self, zap):
        self.zap = zap

    def import_zap_log_from_file(self, filepath, apikey=''):
        """
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'importLogFiles/action/ImportZAPLogFromFile/', {'FilePath': filepath, 'apikey': apikey})))

    def import_mod_security_log_from_file(self, filepath, apikey=''):
        """
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'importLogFiles/action/ImportModSecurityLogFromFile/', {'FilePath': filepath, 'apikey': apikey})))

    def import_zap_http_request_response_pair(self, httprequest, httpresponse, apikey=''):
        """
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'importLogFiles/action/ImportZAPHttpRequestResponsePair/', {'HTTPRequest': httprequest, 'HTTPResponse': httpresponse, 'apikey': apikey})))

    def post_mod_security_audit_event(self, auditeventstring=None, apikey=''):
        """
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'apikey': apikey}
        if auditeventstring is not None:
            params['AuditEventString'] = auditeventstring
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'importLogFiles/action/PostModSecurityAuditEvent/', params)))

    def other_post_mod_security_audit_event(self, auditeventstring, apikey=''):
        """
        This component is optional and therefore the API will only work if it is installed
        """
        return (self.zap._request_other(self.zap.base_other + 'importLogFiles/other/OtherPostModSecurityAuditEvent/', {'AuditEventString': auditeventstring, 'apikey': apikey}))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class alert(object):

    def __init__(self, zap):
        self.zap = zap

    def alert(self, id):
        """
        Gets the alert with the given ID, the corresponding HTTP message can be obtained with the 'messageId' field and 'message' API method
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alert/view/alert/', {'id': id})))

    def alerts(self, baseurl=None, start=None, count=None, riskid=None):
        """
        Gets the alerts raised by ZAP, optionally filtering by URL or riskId, and paginating with 'start' position and 'count' of alerts
        """
        params = {}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        if riskid is not None:
            params['riskId'] = riskid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alert/view/alerts/', params)))

    def alerts_summary(self, baseurl=None):
        """
        Gets number of alerts grouped by each risk level, optionally filtering by URL
        """
        params = {}
        if baseurl is not None:
            params['baseurl'] = baseurl
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alert/view/alertsSummary/', params)))

    def number_of_alerts(self, baseurl=None, riskid=None):
        """
        Gets the number of alerts, optionally filtering by URL or riskId
        """
        params = {}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if riskid is not None:
            params['riskId'] = riskid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alert/view/numberOfAlerts/', params)))

    def alerts_by_risk(self, url=None, recurse=None):
        """
        Gets a summary of the alerts, optionally filtered by a 'url'. If 'recurse' is true then all alerts that apply to urls that start with the specified 'url' will be returned, otherwise only those on exactly the same 'url' (ignoring url parameters)
        """
        params = {}
        if url is not None:
            params['url'] = url
        if recurse is not None:
            params['recurse'] = recurse
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alert/view/alertsByRisk/', params)))

    def alert_counts_by_risk(self, url=None, recurse=None):
        """
        Gets a count of the alerts, optionally filtered as per alertsPerRisk
        """
        params = {}
        if url is not None:
            params['url'] = url
        if recurse is not None:
            params['recurse'] = recurse
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alert/view/alertCountsByRisk/', params)))

    def delete_all_alerts(self, apikey=''):
        """
        Deletes all alerts of the current session.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alert/action/deleteAllAlerts/', {'apikey': apikey})))

    def delete_alert(self, id, apikey=''):
        """
        Deletes the alert with the given ID. 
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alert/action/deleteAlert/', {'id': id, 'apikey': apikey})))

    def update_alerts_confidence(self, ids, confidenceid, apikey=''):
        """
        Update the confidence of the alerts.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alert/action/updateAlertsConfidence/', {'ids': ids, 'confidenceId': confidenceid, 'apikey': apikey})))

    def update_alerts_risk(self, ids, riskid, apikey=''):
        """
        Update the risk of the alerts.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alert/action/updateAlertsRisk/', {'ids': ids, 'riskId': riskid, 'apikey': apikey})))

    def update_alert(self, id, name, riskid, confidenceid, description, param=None, attack=None, otherinfo=None, solution=None, references=None, evidence=None, cweid=None, wascid=None, apikey=''):
        """
        Update the alert with the given ID, with the provided details.
        """
        params = {'id': id, 'name': name, 'riskId': riskid, 'confidenceId': confidenceid, 'description': description, 'apikey': apikey}
        if param is not None:
            params['param'] = param
        if attack is not None:
            params['attack'] = attack
        if otherinfo is not None:
            params['otherInfo'] = otherinfo
        if solution is not None:
            params['solution'] = solution
        if references is not None:
            params['references'] = references
        if evidence is not None:
            params['evidence'] = evidence
        if cweid is not None:
            params['cweId'] = cweid
        if wascid is not None:
            params['wascId'] = wascid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alert/action/updateAlert/', params)))

    def add_alert(self, messageid, name, riskid, confidenceid, description, param=None, attack=None, otherinfo=None, solution=None, references=None, evidence=None, cweid=None, wascid=None, apikey=''):
        """
        Add an alert associated with the given message ID, with the provided details. (The ID of the created alert is returned.)
        """
        params = {'messageId': messageid, 'name': name, 'riskId': riskid, 'confidenceId': confidenceid, 'description': description, 'apikey': apikey}
        if param is not None:
            params['param'] = param
        if attack is not None:
            params['attack'] = attack
        if otherinfo is not None:
            params['otherInfo'] = otherinfo
        if solution is not None:
            params['solution'] = solution
        if references is not None:
            params['references'] = references
        if evidence is not None:
            params['evidence'] = evidence
        if cweid is not None:
            params['cweId'] = cweid
        if wascid is not None:
            params['wascId'] = wascid
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'alert/action/addAlert/', params)))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class reports(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def templates(self):
        """
        View available templates.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'reports/view/templates/')))

    def template_details(self, template):
        """
        View details of the specified template.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'reports/view/templateDetails/', {'template': template})))

    def generate(self, title, template, theme=None, description=None, contexts=None, sites=None, sections=None, includedconfidences=None, includedrisks=None, reportfilename=None, reportfilenamepattern=None, reportdir=None, display=None, apikey=''):
        """
        Generate a report with the supplied parameters.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'title': title, 'template': template, 'apikey': apikey}
        if theme is not None:
            params['theme'] = theme
        if description is not None:
            params['description'] = description
        if contexts is not None:
            params['contexts'] = contexts
        if sites is not None:
            params['sites'] = sites
        if sections is not None:
            params['sections'] = sections
        if includedconfidences is not None:
            params['includedConfidences'] = includedconfidences
        if includedrisks is not None:
            params['includedRisks'] = includedrisks
        if reportfilename is not None:
            params['reportFileName'] = reportfilename
        if reportfilenamepattern is not None:
            params['reportFileNamePattern'] = reportfilenamepattern
        if reportdir is not None:
            params['reportDir'] = reportdir
        if display is not None:
            params['display'] = display
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'reports/action/generate/', params)))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class authorization(object):

    def __init__(self, zap):
        self.zap = zap

    def get_authorization_detection_method(self, contextid):
        """
        Obtains all the configuration of the authorization detection method that is currently set for a context.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'authorization/view/getAuthorizationDetectionMethod/', {'contextId': contextid})))

    def set_basic_authorization_detection_method(self, contextid, headerregex=None, bodyregex=None, statuscode=None, logicaloperator=None, apikey=''):
        """
        Sets the authorization detection method for a context as one that identifies un-authorized messages based on: the message's status code or a regex pattern in the response's header or body. Also, whether all conditions must match or just some can be specified via the logicalOperator parameter, which accepts two values: "AND" (default), "OR".  
        """
        params = {'contextId': contextid, 'apikey': apikey}
        if headerregex is not None:
            params['headerRegex'] = headerregex
        if bodyregex is not None:
            params['bodyRegex'] = bodyregex
        if statuscode is not None:
            params['statusCode'] = statuscode
        if logicaloperator is not None:
            params['logicalOperator'] = logicaloperator
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'authorization/action/setBasicAuthorizationDetectionMethod/', params)))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class exim(object):

    def __init__(self, zap):
        self.zap = zap

    def import_har(self, filepath, apikey=''):
        """
        Imports a HAR file.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'exim/action/importHar/', {'filePath': filepath, 'apikey': apikey})))

    def import_urls(self, filepath, apikey=''):
        """
        Imports URLs (one per line) from the file with the given file system path.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'exim/action/importUrls/', {'filePath': filepath, 'apikey': apikey})))

    def import_zap_logs(self, filepath, apikey=''):
        """
        Imports previously exported ZAP messages from the file with the given file system path.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'exim/action/importZapLogs/', {'filePath': filepath, 'apikey': apikey})))

    def import_modsec_2_logs(self, filepath, apikey=''):
        """
        Imports ModSecurity2 logs from the file with the given file system path.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'exim/action/importModsec2Logs/', {'filePath': filepath, 'apikey': apikey})))

    def export_har(self, baseurl=None, start=None, count=None, apikey=''):
        """
        Gets the HTTP messages sent through/by ZAP, in HAR format, optionally filtered by URL and paginated with 'start' position and 'count' of messages
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'apikey': apikey}
        if baseurl is not None:
            params['baseurl'] = baseurl
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return (self.zap._request_other(self.zap.base_other + 'exim/other/exportHar/', params))

    def export_har_by_id(self, ids, apikey=''):
        """
        Gets the HTTP messages with the given IDs, in HAR format.
        This component is optional and therefore the API will only work if it is installed
        """
        return (self.zap._request_other(self.zap.base_other + 'exim/other/exportHarById/', {'ids': ids, 'apikey': apikey}))

    def send_har_request(self, request, followredirects=None, apikey=''):
        """
        Sends the first HAR request entry, optionally following redirections. Returns, in HAR format, the request sent and response received and followed redirections, if any. The Mode is enforced when sending the request (and following redirections), custom manual requests are not allowed in 'Safe' mode nor in 'Protected' mode if out of scope.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'request': request, 'apikey': apikey}
        if followredirects is not None:
            params['followRedirects'] = followredirects
        return (self.zap._request_other(self.zap.base_other + 'exim/other/sendHarRequest/', params))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class importurls(object):

    def __init__(self, zap):
        self.zap = zap

    def importurls(self, filepath, apikey=''):
        """
        Imports URLs (one per line) from the file with the given file system path.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'importurls/action/importurls/', {'filePath': filepath, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class httpSessions(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def sites(self):
        """
        Gets all of the sites that have sessions.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/view/sites/')))

    def sessions(self, site, session=None):
        """
        Gets the sessions for the given site. Optionally returning just the session with the given name.
        """
        params = {'site': site}
        if session is not None:
            params['session'] = session
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/view/sessions/', params)))

    def active_session(self, site):
        """
        Gets the name of the active session for the given site.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/view/activeSession/', {'site': site})))

    def session_tokens(self, site):
        """
        Gets the names of the session tokens for the given site.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/view/sessionTokens/', {'site': site})))

    @property
    def default_session_tokens(self):
        """
        Gets the default session tokens.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/view/defaultSessionTokens/')))

    def create_empty_session(self, site, session=None, apikey=''):
        """
        Creates an empty session for the given site. Optionally with the given name.
        """
        params = {'site': site, 'apikey': apikey}
        if session is not None:
            params['session'] = session
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/action/createEmptySession/', params)))

    def remove_session(self, site, session, apikey=''):
        """
        Removes the session from the given site.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/action/removeSession/', {'site': site, 'session': session, 'apikey': apikey})))

    def set_active_session(self, site, session, apikey=''):
        """
        Sets the given session as active for the given site.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/action/setActiveSession/', {'site': site, 'session': session, 'apikey': apikey})))

    def unset_active_session(self, site, apikey=''):
        """
        Unsets the active session of the given site.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/action/unsetActiveSession/', {'site': site, 'apikey': apikey})))

    def add_session_token(self, site, sessiontoken, apikey=''):
        """
        Adds the session token to the given site.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/action/addSessionToken/', {'site': site, 'sessionToken': sessiontoken, 'apikey': apikey})))

    def remove_session_token(self, site, sessiontoken, apikey=''):
        """
        Removes the session token from the given site.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/action/removeSessionToken/', {'site': site, 'sessionToken': sessiontoken, 'apikey': apikey})))

    def set_session_token_value(self, site, session, sessiontoken, tokenvalue, apikey=''):
        """
        Sets the value of the session token of the given session for the given site.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/action/setSessionTokenValue/', {'site': site, 'session': session, 'sessionToken': sessiontoken, 'tokenValue': tokenvalue, 'apikey': apikey})))

    def rename_session(self, site, oldsessionname, newsessionname, apikey=''):
        """
        Renames the session of the given site.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/action/renameSession/', {'site': site, 'oldSessionName': oldsessionname, 'newSessionName': newsessionname, 'apikey': apikey})))

    def add_default_session_token(self, sessiontoken, tokenenabled=None, apikey=''):
        """
        Adds a default session token with the given name and enabled state.
        """
        params = {'sessionToken': sessiontoken, 'apikey': apikey}
        if tokenenabled is not None:
            params['tokenEnabled'] = tokenenabled
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/action/addDefaultSessionToken/', params)))

    def set_default_session_token_enabled(self, sessiontoken, tokenenabled, apikey=''):
        """
        Sets whether or not the default session token with the given name is enabled.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/action/setDefaultSessionTokenEnabled/', {'sessionToken': sessiontoken, 'tokenEnabled': tokenenabled, 'apikey': apikey})))

    def remove_default_session_token(self, sessiontoken, apikey=''):
        """
        Removes the default session token with the given name.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'httpSessions/action/removeDefaultSessionToken/', {'sessionToken': sessiontoken, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class localProxies(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def additional_proxies(self):
        """
        Gets all of the additional proxies that have been configured.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'localProxies/view/additionalProxies/')))

    def add_additional_proxy(self, address, port, behindnat=None, alwaysdecodezip=None, removeunsupportedencodings=None, apikey=''):
        """
        Adds an new proxy using the details supplied.
        """
        params = {'address': address, 'port': port, 'apikey': apikey}
        if behindnat is not None:
            params['behindNat'] = behindnat
        if alwaysdecodezip is not None:
            params['alwaysDecodeZip'] = alwaysdecodezip
        if removeunsupportedencodings is not None:
            params['removeUnsupportedEncodings'] = removeunsupportedencodings
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'localProxies/action/addAdditionalProxy/', params)))

    def remove_additional_proxy(self, address, port, apikey=''):
        """
        Removes the additional proxy with the specified address and port.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'localProxies/action/removeAdditionalProxy/', {'address': address, 'port': port, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class brk(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def is_break_all(self):
        """
        Returns True if ZAP will break on both requests and responses
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'break/view/isBreakAll/')))

    @property
    def is_break_request(self):
        """
        Returns True if ZAP will break on requests
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'break/view/isBreakRequest/')))

    @property
    def is_break_response(self):
        """
        Returns True if ZAP will break on responses
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'break/view/isBreakResponse/')))

    @property
    def http_message(self):
        """
        Returns the HTTP message currently intercepted (if any)
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'break/view/httpMessage/')))

    def brk(self, type, state, scope=None, apikey=''):
        """
        Controls the global break functionality. The type may be one of: http-all, http-request or http-response. The state may be true (for turning break on for the specified type) or false (for turning break off). Scope is not currently used.
        """
        params = {'type': type, 'state': state, 'apikey': apikey}
        if scope is not None:
            params['scope'] = scope
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'break/action/break/', params)))

    def set_http_message(self, httpheader, httpbody=None, apikey=''):
        """
        Overwrites the currently intercepted message with the data provided
        """
        params = {'httpHeader': httpheader, 'apikey': apikey}
        if httpbody is not None:
            params['httpBody'] = httpbody
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'break/action/setHttpMessage/', params)))

    def cont(self, apikey=''):
        """
        Submits the currently intercepted message and unsets the global request/response breakpoints
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'break/action/continue/', {'apikey': apikey})))

    def step(self, apikey=''):
        """
        Submits the currently intercepted message, the next request or response will automatically be intercepted
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'break/action/step/', {'apikey': apikey})))

    def drop(self, apikey=''):
        """
        Drops the currently intercepted message
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'break/action/drop/', {'apikey': apikey})))

    def add_http_breakpoint(self, string, location, match, inverse, ignorecase, apikey=''):
        """
        Adds a custom HTTP breakpoint. The string is the string to match. Location may be one of: url, request_header, request_body, response_header or response_body. Match may be: contains or regex. Inverse (match) may be true or false. Lastly, ignorecase (when matching the string) may be true or false.  
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'break/action/addHttpBreakpoint/', {'string': string, 'location': location, 'match': match, 'inverse': inverse, 'ignorecase': ignorecase, 'apikey': apikey})))

    def remove_http_breakpoint(self, string, location, match, inverse, ignorecase, apikey=''):
        """
        Removes the specified breakpoint
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'break/action/removeHttpBreakpoint/', {'string': string, 'location': location, 'match': match, 'inverse': inverse, 'ignorecase': ignorecase, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class websocket(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def channels(self):
        """
        Returns all of the registered web socket channels
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'websocket/view/channels/')))

    def message(self, channelid, messageid):
        """
        Returns full details of the message specified by the channelId and messageId
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'websocket/view/message/', {'channelId': channelid, 'messageId': messageid})))

    def messages(self, channelid=None, start=None, count=None, payloadpreviewlength=None):
        """
        Returns a list of all of the messages that meet the given criteria (all optional), where channelId is a channel identifier, start is the offset to start returning messages from (starting from 0), count is the number of messages to return (default no limit) and payloadPreviewLength is the maximum number bytes to return for the payload contents
        This component is optional and therefore the API will only work if it is installed
        """
        params = {}
        if channelid is not None:
            params['channelId'] = channelid
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        if payloadpreviewlength is not None:
            params['payloadPreviewLength'] = payloadpreviewlength
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'websocket/view/messages/', params)))

    @property
    def break_text_message(self):
        """
        Returns a text representation of an intercepted websockets message
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'websocket/view/breakTextMessage/')))

    def send_text_message(self, channelid, outgoing, message, apikey=''):
        """
        Sends the specified message on the channel specified by channelId, if outgoing is 'True' then the message will be sent to the server and if it is 'False' then it will be sent to the client
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'websocket/action/sendTextMessage/', {'channelId': channelid, 'outgoing': outgoing, 'message': message, 'apikey': apikey})))

    def set_break_text_message(self, message, outgoing, apikey=''):
        """
        Sets the text message for an intercepted websockets message
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'websocket/action/setBreakTextMessage/', {'message': message, 'outgoing': outgoing, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2012 ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
Client implementation for using the ZAP pentesting proxy remotely.
"""

__docformat__ = 'restructuredtext'
__version__ = '0.0.21'

import requests
from requests.packages.urllib3.exceptions import InsecureRequestWarning

from .accessControl import accessControl
from .acsrf import acsrf
from .alert import alert
from .alertFilter import alertFilter
from .ascan import ascan
from .ajaxSpider import ajaxSpider
from .authentication import authentication
from .authorization import authorization
from .automation import automation
from .autoupdate import autoupdate
from .brk import brk
from .context import context
from .core import core
from .exim import exim
from .exportreport import exportreport
from .forcedUser import forcedUser
from .graphql import graphql
from .httpSessions import httpSessions
from .importLogFiles import importLogFiles
from .importurls import importurls
from .localProxies import localProxies
from .network import network
from .openapi import openapi
from .params import params
from .pnh import pnh
from .pscan import pscan
from .replacer import replacer
from .reports import reports
from .retest import retest
from .reveal import reveal
from .revisit import revisit
from .ruleConfig import ruleConfig
from .script import script
from .search import search
from .selenium import selenium
from .sessionManagement import sessionManagement
from .soap import soap
from .spider import spider
from .stats import stats
from .users import users
from .wappalyzer import wappalyzer
from .websocket import websocket


class ZAPv2(object):
    """
    Client API implementation for integrating with ZAP v2.
    """
    base = 'http://zap/JSON/'
    base_other = 'http://zap/OTHER/'

    def __init__(self, proxies=None, apikey=None, validate_status_code=False):
        """
        Creates an instance of the ZAP api client.

        :Parameters:
           - `proxies`: dictionary of ZAP proxies to use.

        Note that all of the other classes in this directory are generated
        new ones will need to be manually added to this file
        """
        self.__proxies = proxies or {
            'http': 'http://127.0.0.1:8080',
            'https': 'http://127.0.0.1:8080'
        }
        self.__apikey = apikey
        self.__validate_status_code=validate_status_code

        self.accessControl = accessControl(self)
        self.acsrf = acsrf(self)
        self.alert = alert(self)
        self.alertFilter = alertFilter(self)
        self.ajaxSpider = ajaxSpider(self)
        self.ascan = ascan(self)
        self.authentication = authentication(self)
        self.authorization = authorization(self)
        self.automation = automation(self)
        self.autoupdate = autoupdate(self)
        self.brk = brk(self)
        self.context = context(self)
        self.core = core(self)
        self.exim = exim(self)
        self.exportreport = exportreport(self)
        self.forcedUser = forcedUser(self)
        self.graphql = graphql(self)
        self.httpsessions = httpSessions(self)
        self.importLogFiles = importLogFiles(self)
        self.importurls = importurls(self)
        self.localProxies = localProxies(self)
        self.network = network(self)
        self.openapi = openapi(self)
        self.params = params(self)
        self.pnh = pnh(self)
        self.pscan = pscan(self)
        self.replacer = replacer(self)
        self.reports = reports(self)
        self.retest = retest(self)
        self.reveal = reveal(self)
        self.revisit = revisit(self)
        self.ruleConfig = ruleConfig(self)
        self.script = script(self)
        self.search = search(self)
        self.selenium = selenium(self)
        self.sessionManagement = sessionManagement(self)
        self.soap = soap(self)
        self.spider = spider(self)
        self.stats = stats(self)
        self.users = users(self)
        self.wappalyzer = wappalyzer(self)
        self.websocket = websocket(self)

        # not very nice, but prevents warnings when accessing the ZAP API via https
        requests.packages.urllib3.disable_warnings(InsecureRequestWarning)

        # Currently create a new session for each request to prevent request failing
        # e.g. when polling the spider status
        #self.session = requests.Session()
        #if apikey is not None:
        #  self.session.headers['X-ZAP-API-Key'] = apikey

    def urlopen(self, url, *args, **kwargs):
        """
        Opens a url forcing the proxies to be used.

        :Parameters:
           - `args`:  all non-keyword arguments.
           - `kwargs`: all other keyword arguments.
        """
        # Must never leak the API key via proxied requests
        return requests.get(url, proxies=self.__proxies, verify=False, *args, **kwargs).text

    def _request_api(self, url, query=None):
        """
        Shortcut for an API request. Will always add the apikey (if defined)

        :Parameters:
           - `url`: the url to GET at.
        """
        if not url.startswith('http://zap/'):
          # Only allow requests to the API so that we never leak the apikey
          raise ValueError('A non ZAP API url was specified ' + url)

        # In theory we should be able to reuse the session,
        # but there have been problems with that
        self.session = requests.Session()
        if self.__apikey is not None:
          self.session.headers['X-ZAP-API-Key'] = self.__apikey

        query = query or {}
        if self.__apikey is not None:
          # Add the apikey to get params for backwards compatibility
          if not query.get('apikey'):
            query['apikey'] = self.__apikey

        response = self.session.get(url, params=query, proxies=self.__proxies, verify=False)

        if (self.__validate_status_code and response.status_code >= 300 and response.status_code < 500):
            raise Exception("Non-successful status code returned from ZAP, which indicates a bad request: "
                                + str(response.status_code)
                                + "response: " + response.text )
        elif (self.__validate_status_code and response.status_code >= 500):
            raise Exception("Non-successful status code returned from ZAP, which indicates a ZAP internal error: "
                                + str(response.status_code)
                                + "response: " + response.text )
        return response

    def _request(self, url, get=None):
        """
        Shortcut for a GET request.

        :Parameters:
           - `url`: the url to GET at.
           - `get`: the dictionary to turn into GET variables.
        """
        data = self._request_api(url, get)
        return data.json()

    def _request_other(self, url, get=None):
        """
        Shortcut for an API OTHER GET request.

        :Parameters:
           - `url`: the url to GET at.
           - `get`: the dictionary to turn into GET variables.
        """
        data = self._request_api(url, get)
        return data.text



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class authentication(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def get_supported_authentication_methods(self):
        """
        Gets the name of the authentication methods.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'authentication/view/getSupportedAuthenticationMethods/')))

    def get_authentication_method_config_params(self, authmethodname):
        """
        Gets the configuration parameters for the authentication method with the given name.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'authentication/view/getAuthenticationMethodConfigParams/', {'authMethodName': authmethodname})))

    def get_authentication_method(self, contextid):
        """
        Gets the name of the authentication method for the context with the given ID.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'authentication/view/getAuthenticationMethod/', {'contextId': contextid})))

    def get_logged_in_indicator(self, contextid):
        """
        Gets the logged in indicator for the context with the given ID.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'authentication/view/getLoggedInIndicator/', {'contextId': contextid})))

    def get_logged_out_indicator(self, contextid):
        """
        Gets the logged out indicator for the context with the given ID.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'authentication/view/getLoggedOutIndicator/', {'contextId': contextid})))

    def set_authentication_method(self, contextid, authmethodname, authmethodconfigparams=None, apikey=''):
        """
        Sets the authentication method for the context with the given ID.
        """
        params = {'contextId': contextid, 'authMethodName': authmethodname, 'apikey': apikey}
        if authmethodconfigparams is not None:
            params['authMethodConfigParams'] = authmethodconfigparams
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'authentication/action/setAuthenticationMethod/', params)))

    def set_logged_in_indicator(self, contextid, loggedinindicatorregex, apikey=''):
        """
        Sets the logged in indicator for the context with the given ID.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'authentication/action/setLoggedInIndicator/', {'contextId': contextid, 'loggedInIndicatorRegex': loggedinindicatorregex, 'apikey': apikey})))

    def set_logged_out_indicator(self, contextid, loggedoutindicatorregex, apikey=''):
        """
        Sets the logged out indicator for the context with the given ID.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'authentication/action/setLoggedOutIndicator/', {'contextId': contextid, 'loggedOutIndicatorRegex': loggedoutindicatorregex, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class script(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def list_engines(self):
        """
        Lists the script engines available
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/view/listEngines/')))

    @property
    def list_types(self):
        """
        Lists the script types available.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/view/listTypes/')))

    @property
    def list_scripts(self):
        """
        Lists the scripts available, with its engine, name, description, type and error state.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/view/listScripts/')))

    def global_var(self, varkey):
        """
        Gets the value of the global variable with the given key. Returns an API error (DOES_NOT_EXIST) if no value was previously set.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/view/globalVar/', {'varKey': varkey})))

    def global_custom_var(self, varkey):
        """
        Gets the value (string representation) of a global custom variable. Returns an API error (DOES_NOT_EXIST) if no value was previously set.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/view/globalCustomVar/', {'varKey': varkey})))

    @property
    def global_vars(self):
        """
        Gets all the global variables (key/value pairs).
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/view/globalVars/')))

    @property
    def global_custom_vars(self):
        """
        Gets all the global custom variables (key/value pairs, the value is the string representation).
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/view/globalCustomVars/')))

    def script_var(self, scriptname, varkey):
        """
        Gets the value of the variable with the given key for the given script. Returns an API error (DOES_NOT_EXIST) if no script with the given name exists or if no value was previously set.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/view/scriptVar/', {'scriptName': scriptname, 'varKey': varkey})))

    def script_custom_var(self, scriptname, varkey):
        """
        Gets the value (string representation) of a custom variable. Returns an API error (DOES_NOT_EXIST) if no script with the given name exists or if no value was previously set.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/view/scriptCustomVar/', {'scriptName': scriptname, 'varKey': varkey})))

    def script_vars(self, scriptname):
        """
        Gets all the variables (key/value pairs) of the given script. Returns an API error (DOES_NOT_EXIST) if no script with the given name exists.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/view/scriptVars/', {'scriptName': scriptname})))

    def script_custom_vars(self, scriptname):
        """
        Gets all the custom variables (key/value pairs, the value is the string representation) of a script. Returns an API error (DOES_NOT_EXIST) if no script with the given name exists.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/view/scriptCustomVars/', {'scriptName': scriptname})))

    def enable(self, scriptname, apikey=''):
        """
        Enables the script with the given name
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/enable/', {'scriptName': scriptname, 'apikey': apikey})))

    def disable(self, scriptname, apikey=''):
        """
        Disables the script with the given name
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/disable/', {'scriptName': scriptname, 'apikey': apikey})))

    def load(self, scriptname, scripttype, scriptengine, filename, scriptdescription=None, charset=None, apikey=''):
        """
        Loads a script into ZAP from the given local file, with the given name, type and engine, optionally with a description, and a charset name to read the script (the charset name is required if the script is not in UTF-8, for example, in ISO-8859-1).
        """
        params = {'scriptName': scriptname, 'scriptType': scripttype, 'scriptEngine': scriptengine, 'fileName': filename, 'apikey': apikey}
        if scriptdescription is not None:
            params['scriptDescription'] = scriptdescription
        if charset is not None:
            params['charset'] = charset
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/load/', params)))

    def remove(self, scriptname, apikey=''):
        """
        Removes the script with the given name
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/remove/', {'scriptName': scriptname, 'apikey': apikey})))

    def run_stand_alone_script(self, scriptname, apikey=''):
        """
        Runs the stand alone script with the given name
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/runStandAloneScript/', {'scriptName': scriptname, 'apikey': apikey})))

    def clear_global_var(self, varkey, apikey=''):
        """
        Clears the global variable with the given key.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/clearGlobalVar/', {'varKey': varkey, 'apikey': apikey})))

    def clear_global_custom_var(self, varkey, apikey=''):
        """
        Clears a global custom variable.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/clearGlobalCustomVar/', {'varKey': varkey, 'apikey': apikey})))

    def clear_global_vars(self, apikey=''):
        """
        Clears the global variables.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/clearGlobalVars/', {'apikey': apikey})))

    def clear_script_var(self, scriptname, varkey, apikey=''):
        """
        Clears the variable with the given key of the given script. Returns an API error (DOES_NOT_EXIST) if no script with the given name exists.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/clearScriptVar/', {'scriptName': scriptname, 'varKey': varkey, 'apikey': apikey})))

    def clear_script_custom_var(self, scriptname, varkey, apikey=''):
        """
        Clears a script custom variable.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/clearScriptCustomVar/', {'scriptName': scriptname, 'varKey': varkey, 'apikey': apikey})))

    def clear_script_vars(self, scriptname, apikey=''):
        """
        Clears the variables of the given script. Returns an API error (DOES_NOT_EXIST) if no script with the given name exists.
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/clearScriptVars/', {'scriptName': scriptname, 'apikey': apikey})))

    def set_script_var(self, scriptname, varkey, varvalue=None, apikey=''):
        """
        Sets the value of the variable with the given key of the given script. Returns an API error (DOES_NOT_EXIST) if no script with the given name exists.
        """
        params = {'scriptName': scriptname, 'varKey': varkey, 'apikey': apikey}
        if varvalue is not None:
            params['varValue'] = varvalue
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/setScriptVar/', params)))

    def set_global_var(self, varkey, varvalue=None, apikey=''):
        """
        Sets the value of the global variable with the given key.
        """
        params = {'varKey': varkey, 'apikey': apikey}
        if varvalue is not None:
            params['varValue'] = varvalue
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'script/action/setGlobalVar/', params)))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class reveal(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def reveal(self):
        """
        Tells if shows hidden fields and enables disabled fields
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'reveal/view/reveal/')))

    def set_reveal(self, reveal, apikey=''):
        """
        Sets if shows hidden fields and enables disabled fields
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'reveal/action/setReveal/', {'reveal': reveal, 'apikey': apikey})))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class ruleConfig(object):

    def __init__(self, zap):
        self.zap = zap

    def rule_config_value(self, key):
        """
        Show the specified rule configuration
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ruleConfig/view/ruleConfigValue/', {'key': key})))

    @property
    def all_rule_configs(self):
        """
        Show all of the rule configurations
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ruleConfig/view/allRuleConfigs/')))

    def reset_rule_config_value(self, key, apikey=''):
        """
        Reset the specified rule configuration, which must already exist
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ruleConfig/action/resetRuleConfigValue/', {'key': key, 'apikey': apikey})))

    def reset_all_rule_config_values(self, apikey=''):
        """
        Reset all of the rule configurations
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ruleConfig/action/resetAllRuleConfigValues/', {'apikey': apikey})))

    def set_rule_config_value(self, key, value=None, apikey=''):
        """
        Set the specified rule configuration, which must already exist
        """
        params = {'key': key, 'apikey': apikey}
        if value is not None:
            params['value'] = value
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ruleConfig/action/setRuleConfigValue/', params)))



# Zed Attack Proxy (ZAP) and its related class files.
#
# ZAP is an HTTP/HTTPS proxy for assessing web application security.
#
# Copyright 2022 the ZAP development team
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
This file was automatically generated.
"""

import six


class ajaxSpider(object):

    def __init__(self, zap):
        self.zap = zap

    @property
    def allowed_resources(self):
        """
        Gets the allowed resources. The allowed resources are always fetched even if out of scope, allowing to include necessary resources (e.g. scripts) from 3rd-parties.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/allowedResources/')))

    @property
    def status(self):
        """
        Gets the current status of the crawler. Actual values are Stopped and Running.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/status/')))

    def results(self, start=None, count=None):
        """
        Gets the current results of the crawler.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {}
        if start is not None:
            params['start'] = start
        if count is not None:
            params['count'] = count
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/results/', params)))

    @property
    def number_of_results(self):
        """
        Gets the number of resources found.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/numberOfResults/')))

    @property
    def full_results(self):
        """
        Gets the full crawled content detected by the AJAX Spider. Returns a set of values based on 'inScope' URLs, 'outOfScope' URLs, and 'errors' encountered during the last/current run of the AJAX Spider.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/fullResults/')))

    @property
    def option_browser_id(self):
        """
        Gets the configured browser to use for crawling.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/optionBrowserId/')))

    @property
    def option_event_wait(self):
        """
        Gets the time to wait after an event (in milliseconds). For example: the wait delay after the cursor hovers over an element, in order for a menu to display, etc.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/optionEventWait/')))

    @property
    def option_max_crawl_depth(self):
        """
        Gets the configured value for the max crawl depth.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/optionMaxCrawlDepth/')))

    @property
    def option_max_crawl_states(self):
        """
        Gets the configured value for the maximum crawl states allowed.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/optionMaxCrawlStates/')))

    @property
    def option_max_duration(self):
        """
        Gets the configured max duration of the crawl, the value is in minutes.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/optionMaxDuration/')))

    @property
    def option_number_of_browsers(self):
        """
        Gets the configured number of browsers to be used.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/optionNumberOfBrowsers/')))

    @property
    def option_reload_wait(self):
        """
        Gets the configured time to wait after reloading the page, this value is in milliseconds.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/optionReloadWait/')))

    @property
    def option_click_default_elems(self):
        """
        Gets the configured value for 'Click Default Elements Only', HTML elements such as 'a', 'button', 'input', all associated with some action or links on the page.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/optionClickDefaultElems/')))

    @property
    def option_click_elems_once(self):
        """
        Gets the value configured for the AJAX Spider to know if it should click on the elements only once.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/optionClickElemsOnce/')))

    @property
    def option_random_inputs(self):
        """
        Gets if the AJAX Spider will use random values in form fields when crawling, if set to true.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/view/optionRandomInputs/')))

    def scan(self, url=None, inscope=None, contextname=None, subtreeonly=None, apikey=''):
        """
        Runs the AJAX Spider against a given target.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'apikey': apikey}
        if url is not None:
            params['url'] = url
        if inscope is not None:
            params['inScope'] = inscope
        if contextname is not None:
            params['contextName'] = contextname
        if subtreeonly is not None:
            params['subtreeOnly'] = subtreeonly
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/scan/', params)))

    def scan_as_user(self, contextname, username, url=None, subtreeonly=None, apikey=''):
        """
        Runs the AJAX Spider from the perspective of a User of the web application.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'contextName': contextname, 'userName': username, 'apikey': apikey}
        if url is not None:
            params['url'] = url
        if subtreeonly is not None:
            params['subtreeOnly'] = subtreeonly
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/scanAsUser/', params)))

    def stop(self, apikey=''):
        """
        Stops the AJAX Spider.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/stop/', {'apikey': apikey})))

    def add_allowed_resource(self, regex, enabled=None, apikey=''):
        """
        Adds an allowed resource.
        This component is optional and therefore the API will only work if it is installed
        """
        params = {'regex': regex, 'apikey': apikey}
        if enabled is not None:
            params['enabled'] = enabled
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/addAllowedResource/', params)))

    def remove_allowed_resource(self, regex, apikey=''):
        """
        Removes an allowed resource.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/removeAllowedResource/', {'regex': regex, 'apikey': apikey})))

    def set_enabled_allowed_resource(self, regex, enabled, apikey=''):
        """
        Sets whether or not an allowed resource is enabled.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/setEnabledAllowedResource/', {'regex': regex, 'enabled': enabled, 'apikey': apikey})))

    def set_option_browser_id(self, string, apikey=''):
        """
        Sets the configuration of the AJAX Spider to use one of the supported browsers.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/setOptionBrowserId/', {'String': string, 'apikey': apikey})))

    def set_option_click_default_elems(self, boolean, apikey=''):
        """
        Sets whether or not the the AJAX Spider will only click on the default HTML elements.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/setOptionClickDefaultElems/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_click_elems_once(self, boolean, apikey=''):
        """
        When enabled, the crawler attempts to interact with each element (e.g., by clicking) only once.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/setOptionClickElemsOnce/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_event_wait(self, integer, apikey=''):
        """
        Sets the time to wait after an event (in milliseconds). For example: the wait delay after the cursor hovers over an element, in order for a menu to display, etc.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/setOptionEventWait/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_crawl_depth(self, integer, apikey=''):
        """
        Sets the maximum depth that the crawler can reach.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/setOptionMaxCrawlDepth/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_crawl_states(self, integer, apikey=''):
        """
        Sets the maximum number of states that the crawler should crawl.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/setOptionMaxCrawlStates/', {'Integer': integer, 'apikey': apikey})))

    def set_option_max_duration(self, integer, apikey=''):
        """
        The maximum time that the crawler is allowed to run.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/setOptionMaxDuration/', {'Integer': integer, 'apikey': apikey})))

    def set_option_number_of_browsers(self, integer, apikey=''):
        """
        Sets the number of windows to be used by AJAX Spider.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/setOptionNumberOfBrowsers/', {'Integer': integer, 'apikey': apikey})))

    def set_option_random_inputs(self, boolean, apikey=''):
        """
        When enabled, inserts random values into form fields.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/setOptionRandomInputs/', {'Boolean': boolean, 'apikey': apikey})))

    def set_option_reload_wait(self, integer, apikey=''):
        """
        Sets the time to wait after the page is loaded before interacting with it.
        This component is optional and therefore the API will only work if it is installed
        """
        return six.next(six.itervalues(self.zap._request(self.zap.base + 'ajaxSpider/action/setOptionReloadWait/', {'Integer': integer, 'apikey': apikey})))
